@@ -2,7 +2,7 @@ from pydantic import (
     BaseModel, validator, root_validator, AnyUrl
 )
 
-from typing import Optional, Dict, List, Union
+from typing import Optional, List, Union
 
 
 # def coord0_less_than_coord1(coord0, length):
@@ -46,52 +46,33 @@ class Polygon(BaseModel):
 
 
 class Classification(BaseModel):
-    name: str
+    model_name: str
     type: str
     value: str
 
 
 class Objects(BaseModel):
-    name: str
+    model_name: str
     type: str
     objects: Union[List[BoundingBox], List[Polygon]]
 
 
-# {
-#     "classifications": [],
-#     "bounding_boxes": [],
-#     "polygons": []
-# }
+class Prediction(BaseModel):
+    id: str
+    name: str
+    confidence: float
 
-# "models": [
-#     "name": "scooter_parking_quality",
-#     "data_labels": "bay_no_bay",
-#     "exclude_classes": ["insufficient_information"]
-# ],
-# "data": [
-#     {
-#         "id": "test",
-#         "url": "https://test.com/1.jpg",
-#         "labels": [
-#             {
-#                 "name": "scooter_parking",
-#                 "type": "classification",
-#                 "value": "in_parking_bay"
-#             },
-#             {
-#                 "name": "scooter_detection",
-#                 "type": "bounding_box",
-#                 "objects": []
-#             }
-#         ]
-#     }
-# ]
+
+class Predictions(BaseModel):
+    prediction_set: List[Prediction]
+    model_name: str
 
 
 class Image(BaseModel):
     id: str
     uri: AnyUrl
     labels: Optional[List[Union[Classification, Objects]]]
+    predictions: Optional[List[Predictions]]
 
     @ validator('uri')
     def check_valid_uri(cls, uri):
